@@ -22,7 +22,7 @@
 *
 *****/
 
-#include "libmissing.h"
+#include "config.h"
 
 #include <stdio.h>
 #include <string.h>
