@@ -22,7 +22,6 @@
 *****/
 
 #include "config.h"
-#include "libmissing.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -30,7 +29,6 @@
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <pthread.h>
 #include <assert.h>
 #include <gnutls/gnutls.h>
 
