@@ -22,7 +22,6 @@
 *****/
 
 #include "config.h"
-#include "libmissing.h"
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -32,14 +31,18 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <netinet/in.h>
-#include <sys/un.h>
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <arpa/inet.h>
-#include <syslog.h>
 #include <assert.h>
 #include <sys/stat.h>
 #include <signal.h>
+#include <netdb.h>
+
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
+# include <syslog.h>
+# include <sys/un.h>
+#endif
 
 #include <libprelude/prelude.h>
 #include <libprelude/prelude-log.h>
@@ -214,17 +217,15 @@ static int authenticate_client(server_generic_t *server, server_generic_client_t
 
 
 
-static int write_connection_cb(void *sdata, server_generic_client_t *client)
+static int write_connection_cb(server_generic_client_t *client)
 {
-        server_generic_t *server = sdata;
-
         assert(!(client->state & SERVER_GENERIC_CLIENT_STATE_CLOSING));
 
         if ( client->state & SERVER_GENERIC_CLIENT_STATE_ACCEPTED )
-                return server->write(client);
+                return client->server->write(client);
         else {
                 server_generic_notify_write_disable(client);
-                return authenticate_client(sdata, client);
+                return authenticate_client(client->server, client);
         }
 }
 
@@ -239,17 +240,16 @@ static int write_connection_cb(void *sdata, server_generic_client_t *client)
  * If the authentication function return -1 (error), this will cause
  * server-logic to call the close_connection_cb callback.
  */
-static int read_connection_cb(void *sdata, server_generic_client_t *client)
+static int read_connection_cb(server_generic_client_t *client)
 {
         int ret = 0;
-        server_generic_t *server = sdata;
 
         assert(!(client->state & SERVER_GENERIC_CLIENT_STATE_CLOSING));
 
         if ( client->state & SERVER_GENERIC_CLIENT_STATE_ACCEPTED )
-                ret = server->read(client);
+                ret = client->server->read(client);
         else
-                ret = authenticate_client(server, client);
+                ret = authenticate_client(client->server, client);
 
         return ret;
 }
@@ -289,16 +289,15 @@ static int do_close_fd(server_generic_client_t *client)
  * if the authentication process succeed for this connection, call
  * the real close() callback function.
  */
-static int close_connection_cb(void *sdata, server_generic_client_t *client)
+static int close_connection_cb(server_generic_client_t *client)
 {
         int ret;
-        server_generic_t *server = sdata;
 
         client->state |= SERVER_GENERIC_CLIENT_STATE_CLOSING;
 
         if ( client->state & SERVER_GENERIC_CLIENT_STATE_ACCEPTED && ! (client->state & SERVER_GENERIC_CLIENT_STATE_CLOSED) ) {
 
-                ret = server->close(client);
+                ret = client->server->close(client);
                 if ( ret < 0 )
                         return ret;
 
@@ -382,11 +381,13 @@ static int setup_client_socket(server_generic_t *server,
         /*
          * set client socket non blocking.
          */
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         ret = fcntl(client, F_SETFL, O_NONBLOCK);
         if ( ret < 0 )
                 return prelude_error_verbose(PRELUDE_ERROR_GENERIC, "could not set non blocking mode for client: %s", strerror(errno));
 
         fcntl(client, F_SETFD, fcntl(client, F_GETFD) | FD_CLOEXEC);
+#endif
 
         ret = prelude_io_new(&cdata->fd);
         if ( ret < 0 )
@@ -441,7 +442,6 @@ static int handle_connection(server_generic_t *server)
 
         client = accept_connection(server, cdata);
         if ( client < 0 ) {
-                prelude_log(PRELUDE_LOG_ERR, "couldn't accept connection.\n");
                 free(cdata);
                 return -1;
         }
@@ -472,7 +472,7 @@ static int handle_connection(server_generic_t *server)
 static void libev_timer_cb(struct ev_loop *loop, struct ev_timer *w, int revents)
 {
         server_generic_client_t *client = w->data;
-        close_connection_cb(client->server, client);
+        close_connection_cb(client);
 }
 
 
@@ -483,14 +483,14 @@ static void libev_notification_cb(struct ev_loop *loop, struct ev_io *w, int rev
 
         if ( ! (cdata->state & SERVER_GENERIC_CLIENT_STATE_CLOSING) ) {
                 if ( revents & EV_WRITE )
-                        ret = write_connection_cb(cdata->server, cdata);
+                        ret = write_connection_cb(cdata);
 
                 if ( ret >= 0 && revents & EV_READ )
-                        ret = read_connection_cb(cdata->server, cdata);
+                        ret = read_connection_cb(cdata);
         }
 
         if ( ret < 0 || cdata->state & SERVER_GENERIC_CLIENT_STATE_CLOSING )
-                ret = close_connection_cb(cdata->server, cdata);
+                ret = close_connection_cb(cdata);
 }
 
 
@@ -549,6 +549,7 @@ static int generic_server(int sock, struct sockaddr *addr, size_t alen)
 
 
 
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
 /*
  * If the UNIX socket already exist, check if it is in use.
  * if it is not, delete it.
@@ -626,7 +627,7 @@ static int unix_server_start(server_generic_t *server)
 
         return 0;
 }
-
+#endif
 
 
 
@@ -660,6 +661,7 @@ static int inet_server_start(server_generic_t *server, struct sockaddr *addr, so
 
 
 
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
 static prelude_bool_t is_unix_addr(const char **out, const char *addr)
 {
         int ret;
@@ -677,6 +679,7 @@ static prelude_bool_t is_unix_addr(const char **out, const char *addr)
 
         return TRUE;
 }
+#endif
 
 
 
@@ -706,22 +709,27 @@ static int do_getaddrinfo(struct addrinfo **ai, const char *addr, unsigned int p
 static int resolve_addr(server_generic_t *server, const char *addr, unsigned int port)
 {
         struct addrinfo *ai;
-        const char *unixpath = NULL;
         int ret, ai_family, ai_addrlen;
 
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
+        const char *unixpath = NULL;
+
         if ( is_unix_addr(&unixpath, addr) ) {
                 ai_family = AF_UNIX;
                 ai_addrlen = sizeof(struct sockaddr_un);
         }
 
         else {
+#endif
                 ret = do_getaddrinfo(&ai, addr, port);
                 if ( ret < 0 )
                         return ret;
 
                 ai_family = ai->ai_family;
                 ai_addrlen = ai->ai_addrlen;
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         }
+#endif
 
         server->sa = malloc(ai_addrlen);
         if ( ! server->sa ) {
@@ -735,10 +743,14 @@ static int resolve_addr(server_generic_t *server, const char *addr, unsigned int
         if ( ai_family != AF_UNIX ) {
                 memcpy(server->sa, ai->ai_addr, ai->ai_addrlen);
                 freeaddrinfo(ai);
-        } else {
+        }
+
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
+        else {
                 struct sockaddr_un *un = (struct sockaddr_un *) server->sa;
                 strncpy(un->sun_path, unixpath, sizeof(un->sun_path));
         }
+#endif
 
         return 0;
 }
@@ -750,18 +762,22 @@ static int sg_bind_common(server_generic_t *server, unsigned int port)
         char out[128];
         void *in_addr;
 
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         fcntl(server->sock, F_SETFD, fcntl(server->sock, F_GETFD) | FD_CLOEXEC);
 
         if ( server->sa->sa_family == AF_UNIX )
                 prelude_log(PRELUDE_LOG_INFO, "server started (listening on %s).\n",
                             ((struct sockaddr_un *) server->sa)->sun_path);
         else {
+#endif
                 in_addr = prelude_sockaddr_get_inaddr(server->sa);
                 assert(in_addr);
 
                 inet_ntop(server->sa->sa_family, in_addr, out, sizeof(out));
                 prelude_log(PRELUDE_LOG_INFO, "server started (listening on %s port %u).\n", out, port);
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         }
+#endif
 
         return 0;
 }
@@ -827,9 +843,11 @@ int server_generic_bind(server_generic_t *server, const char *saddr, unsigned in
         if ( ret < 0 )
                 return ret;
 
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         if ( server->sa->sa_family == AF_UNIX )
                 ret = unix_server_start(server);
         else
+#endif
                 ret = inet_server_start(server, server->sa, server->slen);
 
         if ( ret < 0 ) {
@@ -862,8 +880,10 @@ void server_generic_destroy(server_generic_t *server)
         close(server->sock);
 
         if ( server->sa ) {
+#if ! ((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
                 if ( server->sa->sa_family == AF_UNIX )
                         unlink(((struct sockaddr_un *)server->sa)->sun_path);
+#endif
 
                 free(server->sa);
         }
